Installation
============

With pip (recommended)
-----------------------

Install with pip from PyPi:

.. code-block:: bash

    pip install carebt

From source
-----------

Install from source. :file:`build_and_install.sh` will create a Python-Package (.whl) and install it with pip.

.. code-block:: bash

    $ git clone https://github.com/careBT/carebt_core.git
    $ cd carebt_core
    $ ./build_and_install.sh

Check your installation
-----------------------

.. code-block:: bash

    pip show carebt